import type { DisplayPart, EA, Element, FlattenOptions, Parts } from './MF.types';
import type { GetInfoOptions, GetInfoOptionsAllowed, MFInfo, MFInfoWithParts } from './util/getInfo.types';
import type { IsotopesInfo } from './util/getIsotopesInfo.types';
export interface MFConstructorOptions {
    ensureCase?: boolean;
}
export declare class MF {
    private readonly internal;
    constructor(mf: string, options?: MFConstructorOptions);
    /**
     * Returns an array of objects with kind and value that can be used to easily
     * display the molecular formula.
     */
    toDisplay(): DisplayPart[];
    /**
     * Returns a string that represents the molecular formula adding subscript and superscript in HTML.
     */
    toHtml(): string;
    /**
     * Returns a string that represents the molecular formula adding subscript and superscript
     * using Unicode characters. This can not be parsed anymore so kind of dead end ...
     */
    toText(): string;
    /**
     * Similar to toText but returns a canonic string in which the atoms are sorted using the Hill system
     */
    toCanonicText(): string;
    toParts(options?: {
        expand?: boolean;
    }): Parts[];
    /**
     * Returns an object with the global MF, global charge, monoisotopic mass and mass
     * as well as the same information for all the parts
     */
    getInfo<GIO extends GetInfoOptionsAllowed = GetInfoOptions>(options?: GIO): MFInfo<GIO> | MFInfoWithParts<GIO>;
    /**
     * Returns an object with the elemental analysis
     */
    getEA(): EA[];
    /**
     * Get the different elements for each part
     */
    getElements(): Element[];
    /**
     * Returns an array with each atom and isotopic composition
     */
    getIsotopesInfo(options?: {}): IsotopesInfo | [];
    /**
     * Get a canonized parsable Molecule Formula
     */
    toMF(): string;
    /**
     * Get a canonized MF
     */
    toNeutralMF(): string;
    canonize(): void;
    flatten(options?: FlattenOptions): string[];
}
//# sourceMappingURL=MF.d.ts.map