/** @typedef {import('./util/getIsotopesInfo.types').IsotopesInfo} IsotopesInfo */
/** @typedef {import('./util/getInfo.types').MFInfo} MFInfo */
/** @typedef {import('./util/getInfo.types').MFInfoWithParts} MFInfoWithParts */
/**
 * Class allowing to deal with molecular formula and derived information
 */
export class MFInternal {
    constructor(mf: any, options?: {});
    parsed: any[];
    cache: {};
    /**
     * Returns an array of objects with kind and value that can be used to easily
     * display the molecular formula.
     * @returns {{kind: string, value: string}[]}
     */
    toDisplay(): {
        kind: string;
        value: string;
    }[];
    /**
     * Returns a string that represents the molecular formula adding subscript and superscript in HTML.
     * @returns {string}
     */
    toHtml(): string;
    /**
     * Returns a string that represents the molecular formula adding subscript and superscript
     * using Unicode characters. This can not be parsed anymore so kind of dead end ...
     * @returns {string}
     */
    toText(): string;
    /**
     * Similar to toText but returns a canonic string in which the atoms are sorted using the Hill system
     * @returns {string}
     */
    toCanonicText(): string;
    toParts(options: any): any;
    /**
     * Returns an object with the global MF, global charge, monoisotopic mass and mass
     * as well as the same information for all the parts
     * @param {object} [options={}] options
     * @param {object} [options.customUnsaturations={}] custom unsaturations
     * @param {string} [options.emFieldName='monoisotopicMass'] name of the monoisotopic mass field
     * @param {string} [options.msemFieldName='observedMonoisotopicMass'] name of the observed monoisotopic mass field
     * @returns {MFInfo|MFInfoWithParts}
     */
    getInfo(options?: {
        customUnsaturations?: object;
        emFieldName?: string | undefined;
        msemFieldName?: string | undefined;
    }): MFInfo | MFInfoWithParts;
    /**
     * Returns an object with the elemental analysis
     * @returns {*[]}
     */
    getEA(): any[];
    /**
     * Get the different elements for each part
     * @returns {*[]}
     */
    getElements(): any[];
    /**
     * Returns an array with each atom and isotopic composition
     * @returns {IsotopesInfo}
     */
    getIsotopesInfo(options?: {}): IsotopesInfo;
    /**
     * Get a canonized MF
     * @returns {string}
     */
    toMF(): string;
    /**
     * Get a canonized MF
     * @returns {string}
     */
    toNeutralMF(): string;
    canonize(): void;
    flatten(options: any): string[];
}
export type IsotopesInfo = import("./util/getIsotopesInfo.types").IsotopesInfo;
export type MFInfo = any;
export type MFInfoWithParts = any;
//# sourceMappingURL=MFInternal.d.ts.map